(function( $ ) {
    var root = this, endAnimation = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';

    $.fn.extend({
        animateCss: function (animationName) {
            return this.addClass('animated ' + animationName).one(endAnimation, function() {
                $(this).removeClass('animated ' + animationName);
            });
        }
    });

    root.OW_FloatBox.prototype.setContent = function ( $contents ) {
        var self = this;

        if (typeof $contents == 'string') {
            var $contentsNode = $($contents);

            if (!$contentsNode.length) {
                $contentsNode = $('<span>' + $contents + '</span>');
            }

            $contents = $($contentsNode);
        } else {
            self.$contents_parent = $contents.parent();
        }

        var width, fakeNode;

        if (!self.options.width) {
            fakeNode = $('<div></div>').insertAfter(self.$body);
            fakeNode.attr('class', self.$body.attr('class'));
            fakeNode.css({position: 'absolute',top: -2000, visibility: 'hidden'});
            fakeNode.append($contents);
            width = fakeNode.outerWidth();
        } else {
            width = self.options.width;
        }

        self.$body.empty().append($contents);

        if (fakeNode) {
            fakeNode.remove();
        }

        self.hidePreloader();
        self.fitWindow({width: width});

        root.setTimeout(function () {
            this.trigger('show');
        }.bind(self));

        self.animate(ANIMATE_SETTINGS.show);
    };

    root.OW_FloatBox.prototype.close = function( options )
    {
        var self = this;

        options = $.extend({
            sender: "custom"
        }, options || {});

        if (self.trigger('close', [options]) === false) {
            return false;
        }

        $(document).unbind('keydown', self.esc_listener);

        self.animate(ANIMATE_SETTINGS.close).one(endAnimation, function() {
            var self = this;

            if (self.$title_parent && self.$title_parent.length) {
                self.$title_parent.append(
                    $('.floatbox_title', self.$header).children()
                );
            }

            if (self.$contents_parent && self.$contents_parent.length) {
                self.$contents_parent.append(self.$body.children());
            }

            if (self.$controls_parent && self.$controls_parent.length) {
                self.$controls_parent.append(self.$bottom.children());
            }

            self.$canvas.remove();

            if ($('.floatbox_canvas:visible').length === 0)
            {
                $('html, body').removeClass('floatbox_nooverflow');
                $('#floatbox_overlay, #floatbox_HideSelect').remove();
            }
        }.bind(self));

        window.OWActiveFloatBox = self.parentBox;

        return true;
    };

    root.OW_FloatBox.prototype.animate = function(effect) {
        return this.$container.animateCss(effect);
    };

    root.OwForm.prototype.submitForm = function () {
        var self = this;

        self.removeErrors();

        try {
            self.validate();
        } catch(e) {
            if (self.showErrors){
                OW.error(e);
            }

            var fb = OW.getActiveFloatBox();

            if (fb) {
                fb.animate(ANIMATE_SETTINGS.error);
            }

            return false;
        }

        var dataToSend = self.getValues();

        if (self.trigger('submit', dataToSend) === false) {
            return false;
        }

        var buttons = $('input[type=button], input[type=submit], button', '#' + self.id).addClass('ow_inprogress');

        if (this.ajax) {
            OW.inProgressNode(buttons);

            var postString = '';

            $.each(dataToSend, function (index, data) {
                if ($.isArray(data) || $.isPlainObject(data)) {
                    $.each(data, function (key, value) {
                        postString += index + '[' + key + ']=' + encodeURIComponent(value) + '&';
                    });
                } else {
                    postString += index + '=' + encodeURIComponent(data) + '&';
                }
            });

            $.ajax({
                type: 'post',
                url: self.actionUrl,
                data: postString,
                dataType: self.ajaxDataType,
                success: function (data) {
                    if (self.reset) {
                        self.resetForm();
                    }

                    self.trigger('success', data);

                    if (data && data.hasOwnProperty('result') && !data.result) {
                        var fb = OW.getActiveFloatBox();

                        if (fb) {
                            fb.animate(ANIMATE_SETTINGS.error);
                        }
                    }
                },
                error: function (XMLHttpRequest, textStatus, errorThrown) {
                    OW.error(textStatus);
                    throw textStatus;
                },
                complete: function () {
                    OW.activateNode(buttons);
                }
            });

            return false;
        }

        $.each(self.elements, function(i, o) {
            if ($(o.input).hasClass('invitation')) {
                $(o.input).attr('disabled', 'disabled');
            }
        });

        return true;
    };
}.call(this, jQuery));
